==> grafana_api-0.3.2.tar.gz: grafana_api-0.3.2/grafana_api/api/folder.py <==
from .base import Base


class Folder(Base):
    def __init__(self, api):
        super().__init__(api)
        self.api = api
        self.path = '/users'

    def get_all_folders(self):
        path = '/folders'
        r = self.api.GET(path)
        return r

    def get_folder(self, uid):
        path = '/folders/%s' % (uid)
        r = self.api.GET(path)
        return r

    def create_folder(self, title, uid=None):
        """
        Creates a new folder.

        :param title: The title of the folder.
        :param uid: Optional unique identifier.
        """
        json_data = dict(title=title)
        if uid is not None:
            json_data['uid'] = uid
        return self.api.POST('/folders', json=json_data)

    def update_folder(self, uid, title):
        path = '/folders' % (uid)
        r = self.api.PUT(path, json={
            "title": title
        })
        return r

    def delete_folder(self, uid):
        path = '/folders/%s' % (uid)
        r = self.api.DELETE(path)
        return r

    def get_folder_by_id(self, id):
        path = '/folders/id/%s' % (id)
        r = self.api.GET(path)
        return r

    def get_folder_permissions(self):
        path = '/folders/%s/permissions'
        r = self.api.GET(path)
        return r

    def update_folder_permissions(self, uid, items):
        """
        Updates permissions for a folder.

        This operation will remove existing permissions if they’re not included in the request.

        :param uid: Folder uid
        """
        # TODO really relevant to return something?
        return self.api.POST('/folders/%s/permissions' % uid, json=dict(items=items))

==> grafana_api-0.7.1.tar.gz: grafana_api-0.7.1/grafana_api/api/folder.py <==
from .base import Base


class Folder(Base):
    def __init__(self, api):
        super().__init__(api)
        self.api = api

    def get_all_folders(self):
        """

        :return:
        """
        path = '/folders'
        r = self.api.GET(path)
        return r

    def get_folder(self, uid):
        """

        :param uid:
        :return:
        """
        path = '/folders/%s' % uid
        r = self.api.GET(path)
        return r

    def create_folder(self, title, uid=None):
        """

        :param title:
        :param uid:
        :return:
        """
        json_data = dict(title=title)
        if uid is not None:
            json_data['uid'] = uid
        return self.api.POST('/folders', json=json_data)

    def update_folder(self, uid, title):
        """

        :param uid:
        :param title:
        :return:
        """
        path = '/folders' % uid
        r = self.api.PUT(path, json={
            "title": title
        })
        return r

    def delete_folder(self, uid):
        """

        :param uid:
        :return:
        """
        path = '/folders/%s' % uid
        r = self.api.DELETE(path)
        return r

    def get_folder_by_id(self, folder_id):
        """

        :param folder_id:
        :return:
        """
        path = '/folders/id/%s' % folder_id
        r = self.api.GET(path)
        return r

    def get_folder_permissions(self):
        """

        :return:
        """
        path = '/folders/%s/permissions'
        r = self.api.GET(path)
        return r

    def update_folder_permissions(self, uid, items):
        """

        :param uid:
        :param items:
        :return:
        """
        update_folder_permissions_path = '/folders/%s/permissions' % uid
        r = self.api.POST(update_folder_permissions_path, json=items)
        return r
